yakumo.neutron.v2.floating_ip.Manager

Package yakumo :: Package neutron :: Package v2 :: Module floating_ip :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for floating IPs in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for floating IPs in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.floating_ip.Resource |
create(self, project=`'``__UNDEF__``'`, floating_network=`'``__UNDEF__``'`, fixed_ip=`'``__UNDEF__``'`, floating_ip=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) Aquire a floating IP address | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``floatingip``'``
| _json_resources_key = ``'``floatingips``'``
| _url_resource_path = ``'``/v2.0/floatingips``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, project=`'``__UNDEF__``'`, floating_network=`'``__UNDEF__``'`, fixed_ip=`'``__UNDEF__``'`, floating_ip=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) | source code
Aquire a floating IP address Parameters: `project` (yakumo.project.Resource) - Project `floating_network` (yakumo.neutron.v2.network.Resource) - Network `fixed_ip` (str) - Fixed IP address to map `port` (yakumo.neutron.v2.port) - Port Returns: yakumo.neutron.v2.floating_ip.Resource Mapped Floating IP address Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('floating_network', 'floating_network_id', ma
      pper.Resource('neutron.network')), ('floating_ip', 'floating_ip_addres
      s', mapper.Noop), ('fixed_ip', 'fixed_ip_address', mapper.Noop), ('rou
      ter', 'router_id', mapper.Resource('neutron.router')), ('port', 'port_
      id', mapper.Resource('neutron.port')), ('project', 'tenant_id', mapper
      .Resource('project')),]